Customized printing methods for several objects used in TunePareto: For TuneParetoResult objects, the Pareto-optimal parameter configurations are printed. For TuneParetoClassifier and TuneParetoModel objects, information on the classifier and its parameters is printed.
# S3 method for TuneParetoResult
print(x, ...)
# S3 method for TuneParetoClassifier
print(x, ...)
# S3 method for TuneParetoModel
print(x, ...)Invisibly returns the printed object.
An object of class TuneParetoResult, TuneParetoClassifier or TuneParetoModel to be printed.
Further parameters (currently unused).
tunePareto, tuneParetoClassifier, trainTuneParetoClassifier